/*******************************************************************************
* File Name: CLK10.h
* Version 2.20
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_CLOCK_CLK10_H)
#define CY_CLOCK_CLK10_H

#include <cytypes.h>
#include <cyfitter.h>


/***************************************
* Conditional Compilation Parameters
***************************************/

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component cy_clock_v2_20 requires cy_boot v3.0 or later
#endif /* (CY_PSOC5LP) */


/***************************************
*        Function Prototypes
***************************************/

void CLK10_Start(void) ;
void CLK10_Stop(void) ;

#if(CY_PSOC3 || CY_PSOC5LP)
void CLK10_StopBlock(void) ;
#endif /* (CY_PSOC3 || CY_PSOC5LP) */

void CLK10_StandbyPower(uint8 state) ;
void CLK10_SetDividerRegister(uint16 clkDivider, uint8 restart) 
                                ;
uint16 CLK10_GetDividerRegister(void) ;
void CLK10_SetModeRegister(uint8 modeBitMask) ;
void CLK10_ClearModeRegister(uint8 modeBitMask) ;
uint8 CLK10_GetModeRegister(void) ;
void CLK10_SetSourceRegister(uint8 clkSource) ;
uint8 CLK10_GetSourceRegister(void) ;
#if defined(CLK10__CFG3)
void CLK10_SetPhaseRegister(uint8 clkPhase) ;
uint8 CLK10_GetPhaseRegister(void) ;
#endif /* defined(CLK10__CFG3) */

#define CLK10_Enable()                       CLK10_Start()
#define CLK10_Disable()                      CLK10_Stop()
#define CLK10_SetDivider(clkDivider)         CLK10_SetDividerRegister(clkDivider, 1u)
#define CLK10_SetDividerValue(clkDivider)    CLK10_SetDividerRegister((clkDivider) - 1u, 1u)
#define CLK10_SetMode(clkMode)               CLK10_SetModeRegister(clkMode)
#define CLK10_SetSource(clkSource)           CLK10_SetSourceRegister(clkSource)
#if defined(CLK10__CFG3)
#define CLK10_SetPhase(clkPhase)             CLK10_SetPhaseRegister(clkPhase)
#define CLK10_SetPhaseValue(clkPhase)        CLK10_SetPhaseRegister((clkPhase) + 1u)
#endif /* defined(CLK10__CFG3) */


/***************************************
*             Registers
***************************************/

/* Register to enable or disable the clock */
#define CLK10_CLKEN              (* (reg8 *) CLK10__PM_ACT_CFG)
#define CLK10_CLKEN_PTR          ((reg8 *) CLK10__PM_ACT_CFG)

/* Register to enable or disable the clock */
#define CLK10_CLKSTBY            (* (reg8 *) CLK10__PM_STBY_CFG)
#define CLK10_CLKSTBY_PTR        ((reg8 *) CLK10__PM_STBY_CFG)

/* Clock LSB divider configuration register. */
#define CLK10_DIV_LSB            (* (reg8 *) CLK10__CFG0)
#define CLK10_DIV_LSB_PTR        ((reg8 *) CLK10__CFG0)
#define CLK10_DIV_PTR            ((reg16 *) CLK10__CFG0)

/* Clock MSB divider configuration register. */
#define CLK10_DIV_MSB            (* (reg8 *) CLK10__CFG1)
#define CLK10_DIV_MSB_PTR        ((reg8 *) CLK10__CFG1)

/* Mode and source configuration register */
#define CLK10_MOD_SRC            (* (reg8 *) CLK10__CFG2)
#define CLK10_MOD_SRC_PTR        ((reg8 *) CLK10__CFG2)

#if defined(CLK10__CFG3)
/* Analog clock phase configuration register */
#define CLK10_PHASE              (* (reg8 *) CLK10__CFG3)
#define CLK10_PHASE_PTR          ((reg8 *) CLK10__CFG3)
#endif /* defined(CLK10__CFG3) */


/**************************************
*       Register Constants
**************************************/

/* Power manager register masks */
#define CLK10_CLKEN_MASK         CLK10__PM_ACT_MSK
#define CLK10_CLKSTBY_MASK       CLK10__PM_STBY_MSK

/* CFG2 field masks */
#define CLK10_SRC_SEL_MSK        CLK10__CFG2_SRC_SEL_MASK
#define CLK10_MODE_MASK          (~(CLK10_SRC_SEL_MSK))

#if defined(CLK10__CFG3)
/* CFG3 phase mask */
#define CLK10_PHASE_MASK         CLK10__CFG3_PHASE_DLY_MASK
#endif /* defined(CLK10__CFG3) */

#endif /* CY_CLOCK_CLK10_H */


/* [] END OF FILE */
