/*******************************************************************************
* File Name: InPin.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_InPin_H) /* Pins InPin_H */
#define CY_PINS_InPin_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "InPin_aliases.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 InPin__PORT == 15 && ((InPin__MASK & 0xC0) != 0))


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    InPin_Write(uint8 value);
void    InPin_SetDriveMode(uint8 mode);
uint8   InPin_ReadDataReg(void);
uint8   InPin_Read(void);
void    InPin_SetInterruptMode(uint16 position, uint16 mode);
uint8   InPin_ClearInterrupt(void);
/** @} general */

/***************************************
*           API Constants        
***************************************/
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the InPin_SetDriveMode() function.
     *  @{
     */
        #define InPin_DM_ALG_HIZ         PIN_DM_ALG_HIZ
        #define InPin_DM_DIG_HIZ         PIN_DM_DIG_HIZ
        #define InPin_DM_RES_UP          PIN_DM_RES_UP
        #define InPin_DM_RES_DWN         PIN_DM_RES_DWN
        #define InPin_DM_OD_LO           PIN_DM_OD_LO
        #define InPin_DM_OD_HI           PIN_DM_OD_HI
        #define InPin_DM_STRONG          PIN_DM_STRONG
        #define InPin_DM_RES_UPDWN       PIN_DM_RES_UPDWN
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define InPin_MASK               InPin__MASK
#define InPin_SHIFT              InPin__SHIFT
#define InPin_WIDTH              4u

/* Interrupt constants */
#if defined(InPin__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in InPin_SetInterruptMode() function.
     *  @{
     */
        #define InPin_INTR_NONE      (uint16)(0x0000u)
        #define InPin_INTR_RISING    (uint16)(0x0001u)
        #define InPin_INTR_FALLING   (uint16)(0x0002u)
        #define InPin_INTR_BOTH      (uint16)(0x0003u) 
    /** @} intrMode */
/** @} group_constants */

    #define InPin_INTR_MASK      (0x01u) 
#endif /* (InPin__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define InPin_PS                     (* (reg8 *) InPin__PS)
/* Data Register */
#define InPin_DR                     (* (reg8 *) InPin__DR)
/* Port Number */
#define InPin_PRT_NUM                (* (reg8 *) InPin__PRT) 
/* Connect to Analog Globals */                                                  
#define InPin_AG                     (* (reg8 *) InPin__AG)                       
/* Analog MUX bux enable */
#define InPin_AMUX                   (* (reg8 *) InPin__AMUX) 
/* Bidirectional Enable */                                                        
#define InPin_BIE                    (* (reg8 *) InPin__BIE)
/* Bit-mask for Aliased Register Access */
#define InPin_BIT_MASK               (* (reg8 *) InPin__BIT_MASK)
/* Bypass Enable */
#define InPin_BYP                    (* (reg8 *) InPin__BYP)
/* Port wide control signals */                                                   
#define InPin_CTL                    (* (reg8 *) InPin__CTL)
/* Drive Modes */
#define InPin_DM0                    (* (reg8 *) InPin__DM0) 
#define InPin_DM1                    (* (reg8 *) InPin__DM1)
#define InPin_DM2                    (* (reg8 *) InPin__DM2) 
/* Input Buffer Disable Override */
#define InPin_INP_DIS                (* (reg8 *) InPin__INP_DIS)
/* LCD Common or Segment Drive */
#define InPin_LCD_COM_SEG            (* (reg8 *) InPin__LCD_COM_SEG)
/* Enable Segment LCD */
#define InPin_LCD_EN                 (* (reg8 *) InPin__LCD_EN)
/* Slew Rate Control */
#define InPin_SLW                    (* (reg8 *) InPin__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define InPin_PRTDSI__CAPS_SEL       (* (reg8 *) InPin__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define InPin_PRTDSI__DBL_SYNC_IN    (* (reg8 *) InPin__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define InPin_PRTDSI__OE_SEL0        (* (reg8 *) InPin__PRTDSI__OE_SEL0) 
#define InPin_PRTDSI__OE_SEL1        (* (reg8 *) InPin__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define InPin_PRTDSI__OUT_SEL0       (* (reg8 *) InPin__PRTDSI__OUT_SEL0) 
#define InPin_PRTDSI__OUT_SEL1       (* (reg8 *) InPin__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define InPin_PRTDSI__SYNC_OUT       (* (reg8 *) InPin__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(InPin__SIO_CFG)
    #define InPin_SIO_HYST_EN        (* (reg8 *) InPin__SIO_HYST_EN)
    #define InPin_SIO_REG_HIFREQ     (* (reg8 *) InPin__SIO_REG_HIFREQ)
    #define InPin_SIO_CFG            (* (reg8 *) InPin__SIO_CFG)
    #define InPin_SIO_DIFF           (* (reg8 *) InPin__SIO_DIFF)
#endif /* (InPin__SIO_CFG) */

/* Interrupt Registers */
#if defined(InPin__INTSTAT)
    #define InPin_INTSTAT            (* (reg8 *) InPin__INTSTAT)
    #define InPin_SNAP               (* (reg8 *) InPin__SNAP)
    
	#define InPin_0_INTTYPE_REG 		(* (reg8 *) InPin__0__INTTYPE)
	#define InPin_1_INTTYPE_REG 		(* (reg8 *) InPin__1__INTTYPE)
	#define InPin_2_INTTYPE_REG 		(* (reg8 *) InPin__2__INTTYPE)
	#define InPin_3_INTTYPE_REG 		(* (reg8 *) InPin__3__INTTYPE)
#endif /* (InPin__INTSTAT) */

#endif /* CY_PSOC5A... */

#endif /*  CY_PINS_InPin_H */


/* [] END OF FILE */
